@@ -3,11 +3,8 @@ package App::Rgit;
 use strict;
 use warnings;
 
-use Object::Tiny qw/config command/;
-
 use App::Rgit::Command;
 use App::Rgit::Config;
-use App::Rgit::Utils qw/validate/;
 
 =head1 NAME
 
@@ -15,11 +12,11 @@ App::Rgit - Backend that supports the rgit utility.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 DESCRIPTION
 
@@ -36,23 +33,29 @@ Creates a new L<App::Rgit> object that's bound to execute the command C<$cmd> on
 =cut
 
 sub new {
- my ($class, %args) = &validate;
+ my $class = shift;
+ $class = ref $class || $class;
+
+ my %args = @_;
+
  my $config = App::Rgit::Config->new(
   root  => $args{root},
   git   => $args{git},
   debug => $args{debug},
  );
  return unless defined $config;
+
  my $command = App::Rgit::Command->new(
   cmd    => $args{cmd},
   args   => $args{args},
   policy => $args{policy},
  );
  return unless defined $command;
- $class->SUPER::new(
+
+ bless {
   config  => $config,
   command => $command,
- );
+ }, $class;
 }
 
 =head2 C<run>
@@ -63,6 +66,7 @@ Actually run the commands.
 
 sub run {
  my $self = shift;
+
  $self->command->run($self->config);
 }
 
@@ -70,7 +74,13 @@ sub run {
 
 =head2 C<command>
 
-Accessors.
+Read-only accessors.
+
+=cut
+
+BEGIN {
+ eval "sub $_ { \$_[0]->{$_} }" for qw/config command/;
+}
 
 =head1 SEE ALSO
 
@@ -79,12 +89,13 @@ L<rgit>.
 =head1 AUTHOR
 
 Vincent Pit, C<< <perl at profvince.com> >>, L<http://profvince.com>.
-   
+
 You can contact me by mail or on C<irc.perl.org> (vincent).
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -94,7 +105,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2009 Vincent Pit, all rights reserved.
+Copyright 2008,2009,2010 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
