@@ -15,11 +15,11 @@ App::Rgit::Config::Default - Default App::Rgit configuration class.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 DESCRIPTION
 
@@ -43,12 +43,15 @@ sub repos {
  my %repos;
  find {
   wanted => sub {
-   return unless -d $_;
-   my $r = App::Rgit::Repository->new(dir => $File::Find::name);
-   $repos{$r->repo} = $r if $r 
-                         and not exists $repos{$r->repo};
+   return if m{(?:^|/)\.\.?$}
+          or not (-d $_ and -r _);
+   if (my $r = App::Rgit::Repository->new(dir => $_)) {
+    $File::Find::prune = 1;
+    $repos{$r->repo} = $r unless exists $repos{$r->repo};
+   }
   },
-  follow => 1
+  follow   => 1,
+  no_chdir => 1,
  }, $self->root;
  $self->{repos} = [ sort { $a->repo cmp $b->repo } values %repos ];
 }
@@ -57,6 +60,8 @@ sub repos {
 
 L<rgit>.
 
+L<App::Rgit::Config>.
+
 =head1 AUTHOR
 
 Vincent Pit, C<< <perl at profvince.com> >>, L<http://profvince.com>.
@@ -65,7 +70,8 @@ You can contact me by mail or on C<irc.perl.org> (vincent).
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -75,7 +81,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2009 Vincent Pit, all rights reserved.
+Copyright 2008,2009,2010 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
