@@ -3,32 +3,34 @@ package App::Rgit::Repository;
 use strict;
 use warnings;
 
-use Cwd qw/cwd abs_path/;
-use File::Spec::Functions qw/canonpath catdir splitdir abs2rel file_name_is_absolute/;
-use POSIX qw/WIFEXITED WEXITSTATUS WIFSIGNALED WTERMSIG SIGINT SIGQUIT/;
+use Cwd        (); # cwd, abs_path
+use File::Spec (); # canonpath, catdir, splitdir, abs2rel
+use POSIX      (); # WIFEXITED WEXITSTATUS WIFSIGNALED WTERMSIG SIGINT SIGQUIT
+
+my ($WIFEXITED, $WEXITSTATUS, $WIFSIGNALED, $WTERMSIG);
 
 BEGIN {
- no warnings 'redefine';
- *WIFEXITED   = sub { 1 }             unless eval { WIFEXITED(0);   1 };
- *WEXITSTATUS = sub { shift() >> 8 }  unless eval { WEXITSTATUS(0); 1 };
- *WIFSIGNALED = sub { shift() & 127 } unless eval { WIFSIGNALED(0); 1 };
+ $WIFEXITED   = eval { POSIX::WIFEXITED(0);   1 } ? \&POSIX::WIFEXITED
+                                                  : sub { 1 };
+ $WEXITSTATUS = eval { POSIX::WEXITSTATUS(0); 1 } ? \&POSIX::WEXITSTATUS
+                                                  : sub { shift() >> 8 };
+ $WIFSIGNALED = eval { POSIX::WIFSIGNALED(0); 1 } ? \&POSIX::WIFSIGNALED
+                                                  : sub { shift() & 127 };
+ $WTERMSIG    = eval { POSIX::WTERMSIG(0);    1 } ? \&POSIX::WTERMSIG
+                                                  : sub { shift() & 127 };
 }
 
-use Object::Tiny qw/fake repo bare name work/;
-
-use App::Rgit::Utils qw/validate/;
-
 =head1 NAME
 
 App::Rgit::Repository - Class representing a Git repository.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 DESCRIPTION
 
@@ -46,46 +48,54 @@ If the C<fake> option is passed, C<$dir> isn't checked to be a valid C<git> repo
 =cut
 
 sub new {
- my ($class, %args) = &validate;
+ my $class = shift;
+ $class = ref $class || $class;
+
+ my %args = @_;
+
  my $dir = $args{dir};
- $dir = abs_path $dir if defined $dir and not file_name_is_absolute $dir;
- $dir = cwd       unless defined $dir;
+ if (defined $dir) {
+  $dir = Cwd::abs_path($dir);
+ } else {
+  $dir = Cwd::cwd;
+ }
+ $dir = File::Spec->canonpath($dir);
+
  my ($repo, $bare, $name, $work);
  if ($args{fake}) {
   $repo = $work = $dir;
- } else { 
-  my @tries = ($dir);
-  my @chunks = splitdir $dir;
-  my $last = pop @chunks;
-  push @tries, "$dir.git" unless $last =~ /\.git$/;
-  push @tries, catdir($dir, '.git') unless $last eq '.git';
-  for (@tries) {
-   if (-d $_ && -d "$_/refs" and -d "$_/objects" and -e "$_/HEAD") {
-    $repo = $_;
-    last;
-   }
-  }
-  return unless defined $repo;
-  $repo = canonpath $repo;
-  @chunks = splitdir $repo;
-  $last = pop @chunks;
-  if ($last eq '.git') {
+ } else {
+  return unless -d $dir
+            and -d "$dir/refs"
+            and -d "$dir/objects"
+            and -e "$dir/HEAD";
+
+  my @chunks = File::Spec->splitdir($dir);
+  my $last   = pop @chunks;
+  return unless defined $last;
+
+  if (@chunks and $last eq '.git') {
    $bare = 0;
    $name = $chunks[-1];
-   $work = catdir @chunks;
-  } else {
+   $work = File::Spec->catdir(@chunks);
+  } elsif ($last =~ /(.+)\.git$/) {
    $bare = 1;
-   ($name) = $last =~ /(.*)\.git$/;
-   $work = $repo;
+   $name = $1;
+   $work = File::Spec->catdir(@chunks, $last);
+  } else {
+   return;
   }
+
+  $repo = $dir;
  }
- $class->SUPER::new(
+
+ bless {
   fake => !!$args{fake},
   repo => $repo,
   bare => $bare,
   name => $name,
   work => $work,
- );
+ }, $class;
 }
 
 =head2 C<chdir>
@@ -112,22 +122,25 @@ Returns the exit code.
 
 =cut
 
-sub _abs2rel {
- my $a = &abs2rel;
+my $abs2rel = sub {
+ my $a = File::Spec->abs2rel(@_);
  $a = $_[0] unless defined $a;
  $a;
-}
+};
 
 my %escapes = (
  '%' => sub { '%' },
  'n' => sub { shift->name },
- 'g' => sub { _abs2rel(shift->repo, shift->root) },
+ 'g' => sub { $abs2rel->(shift->repo, shift->root) },
  'G' => sub { shift->repo },
- 'w' => sub { _abs2rel(shift->work, shift->root) },
+ 'w' => sub { $abs2rel->(shift->work, shift->root) },
  'W' => sub { shift->work },
  'b' => sub {
   my ($self, $conf) = @_;
-  _abs2rel($self->bare ? $self->repo : $self->work . '.git', $conf->root)
+  $abs2rel->(
+   $self->bare ? $self->repo : $self->work . '.git',
+   $conf->root
+  );
  },
  'B' => sub { $_[0]->bare ? $_[0]->repo : $_[0]->work . '.git' },
  'R' => sub { $_[1]->root },
@@ -139,34 +152,41 @@ sub run {
  my $self = shift;
  my $conf = shift;
  return unless $conf->isa('App::Rgit::Config');
+
  my @args = @_;
+
  unless ($self->fake) {
   s/%($e)/$escapes{$1}->($self, $conf)/eg for @args;
  }
+
  unshift @args, $conf->git;
  $conf->info('Executing "', join(' ', @args), '" into ', $self->work, "\n");
+
  {
   local $ENV{GIT_DIR} = $self->repo if exists $ENV{GIT_DIR};
   local $ENV{GIT_EXEC_PATH} = $conf->git if exists $ENV{GIT_EXEC_PATH};
   system { $args[0] } @args;
  }
+
  if ($? == -1) {
   $conf->crit("Failed to execute git: $!\n");
   return;
  }
+
  my $ret;
- $ret = WEXITSTATUS($?) if WIFEXITED($?);
+ $ret = $WEXITSTATUS->($?) if $WIFEXITED->($?);
  my $sig;
- if (WIFSIGNALED($?)) {
-  $sig = WTERMSIG($?);
+ if ($WIFSIGNALED->($?)) {
+  $sig = $WTERMSIG->($?);
   $conf->warn("git died with signal $sig\n");
-  if ($sig == SIGINT || $sig == SIGQUIT) {
+  if ($sig == POSIX::SIGINT() || $sig == POSIX::SIGQUIT()) {
    $conf->err("Aborting\n");
    exit $sig;
   }
  } elsif ($ret) {
   $conf->info("git returned $ret\n");
  }
+
  return wantarray ? ($ret, $sig) : $ret;
 }
 
@@ -180,7 +200,13 @@ sub run {
 
 =head2 C<work>
 
-Accessors.
+Read-only accessors.
+
+=cut
+
+BEGIN {
+ eval "sub $_ { \$_[0]->{$_} }" for qw/fake repo bare name work/;
+}
 
 =head1 SEE ALSO
 
@@ -189,12 +215,13 @@ L<rgit>.
 =head1 AUTHOR
 
 Vincent Pit, C<< <perl at profvince.com> >>, L<http://profvince.com>.
-   
+
 You can contact me by mail or on C<irc.perl.org> (vincent).
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-rgit at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=rgit>.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -204,7 +231,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2009 Vincent Pit, all rights reserved.
+Copyright 2008,2009,2010 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
